==> libdclaf90-0.37.tar.gz: libdclaf90-0.37/manual/dcl_nml_make.rb <==
#########################################
# ܥץȤ dcl-f90 ץ   #
# ¹Ԥ뤿 namelist ÷  #
# 륹ץȤǤ.               #
# , GTK Ѥƥե  #
# ǤФȻפޤ.                   #
# 2010/11/27 ҵ                   #
#########################################
$KCODE = "euc-jp"

def val_make(vname,input_name)
# vname = ѿ̾, input_name = Ϥѿơܸġ
puts "#{input_name} ϤƲ. [#{vname}]"
val = gets()
str = "#{vname} = #{val}"
puts str
return str
end

def val_make_opt(vname,input_name,opt)
# val_make Υǥեͤ˷ޤäƤ
# ξǤ, ǥեͤϤʤФʤʤ(ײ)
# vname = ѿ̾, input_name = Ϥѿơܸġ
puts "#{input_name} ϤƲ. [#{vname}]"
puts "ǥեͤ [#{vname} = #{opt}] Ǥ."
val = gets()
str = "#{vname} = #{val}"
puts str
return str
end


mae = <<"EOF"
ˤ.
줫 DCL-f90 ¹Ԥ뤿 namelist ե
ԤåץȤưޤ.
ʤ, ʲμƲ.
ޤ, ȯʳˤ뤿, 顼ʤɤϰڹԤäƤʤΤ,
жʻȤϤʤǤ.
ȤǤʤ顼򾷤.

ʤǤʤ, "yes", ưʤʤ "no" ϤƲ.
EOF

puts mae

str1 = gets()

if str1=="no\n"
   puts 'ޤۤ.'
   return 0
end

puts str1

####### Section 1 #########
puts "Section 1 : &input ."
puts "ΥǤ, ׻ΰʻʤɤνפԤޤ."

s = "γʻ"
input_str = "&input\n"+val_make( "nx", s )

s = "γʻ"
input_str = input_str+val_make( "ny", s )

s = "ľγʻ"
input_str = input_str+val_make( "nz", s )

s = "üκɸ"
input_str = input_str+val_make_opt( "xmin", s, 0.0 )

s = "üκɸ"
input_str = input_str+val_make_opt( "ymin", s, 0.0 )

s = "ľβüκɸ"
input_str = input_str+val_make( "zmin", s )

s = "γʻҴֳ [m]"
input_str = input_str+val_make( "dx", s )

s = "γʻҴֳ [m]"
input_str = input_str+val_make( "dy", s )

s = "ľγʻҴֳ [m]"
input_str = input_str+val_make( "dz", s )
# , ȥåץˤбƤޤ.

s = "ɤ߹ե"
input_str = input_str+val_make( "fnumber", s )

s = "ɤ߹եλֳִ֡Ϣֳִ֡ [integer]"
input_str = input_str+val_make( "dt", s )

s = "ɤ߹ geography եκ쥳ֹ"
input_str = input_str+val_make( "grd_rec", s )

s = "ɤʬ"
input_str = input_str+val_make( "shade_num", s )

s = "顼ɤκ"
input_str = input_str+val_make( "cmin", s )

s = "顼ɤκ"
input_str = input_str+val_make( "cmax", s )

s = "κ"
input_str = input_str+val_make( "contmin", s )

s = "κ"
input_str = input_str+val_make( "contmax", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 1 (&input) μϽλޤ."

####### Section 2 #########
puts "Section 2 : &filename ."
puts "ΥǤ, ɤ߹եΥإåɤ߹ߤ򳫻ϤեԤޤ."

s = "ɤ߹եΥإå [char]"
str1 =<<"EOE" 
[] : ΥץǤ, ɤ߹եֳ֤Ϣ֤ȤʤäƤ뤳ȤꤷƤޤ.
ä, ϤإåȤ, Ϣ֤οľޤǤؤޤΤ,
Ϥʸ, Ϣ֤ľޤǤΥե̾Ȥʤޤ.
ʤ, ʲμ, [char] ɽΤѿˤĤƤ, ϻ˥󥰥륯ơǰϤǲ.
EOE
puts str1
input_str = input_str+"&filename\n"+val_make( "hname", s )

s = "ɤ߹եΥեå (ĥҤޤϢֹľ) [char]"
input_str = input_str+val_make( "footname", s )

s = "ɤ߹եϢ֤κǤͤ"
input_str = input_str+val_make( "ininame", s )

s = "geography ե̾ [char]"
input_str = input_str+val_make( "grdname", s )

s = "դΥȥ̾ [char]"
str1 =<<"EOE" 
[] : Ǥ륿ȥ̾ DCL ΰʸ¤˰¸ޤ. ʤ, ȥθźǻ֤ͤˤʤäƤΤ, θꤷƤ.
EOE
puts str1
input_str = input_str+val_make( "title_name", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 2 (&filename) μϽλޤ."

####### Section 3 #########
puts "Section 3 : &file_form ."
puts "ΥǤ, DCL ΥդɽͤΥեޥåԤޤ."

s = "ɽͤΥեޥå [(f?.?), char]"
input_str = input_str+"&file_form\n"+val_make( "form_typec", s )

s = "顼СɽͤΥեޥå [(f?.?), char]"
input_str = input_str+val_make( "form_types", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 3 (&file_form) μϽλޤ."

####### Section 4 #########
puts "Section 4 : &dcl_dump ."
puts "ΥǤ, DCL Υ֤˴ؤԤޤ."

s = "դե¸뤫ɤ [.false., .true.]"
str1 =<<"EOD"
[] : ʲꤹ IWS ͤ 2 ξ϶Ū¸ޤ.
EOD
puts str1
input_str = input_str+"&dcl_dump\n"+val_make( "ldump", s )

s = "Return 򲡤Ʋڡ뤫ɤ [.false., .true.]"
input_str = input_str+val_make( "lwait", s )

s = "Return 򲡤ƥդν֤Ĥɤ [.false., .true.]"
input_str = input_str+val_make( "lwait1", s )

s = "DCL νֹ [integer]"
input_str = input_str+val_make( "IWS", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 4 (&dcl_dump) μϽλޤ."

####### Section 5 #########
puts "Section 5 : &map_info ."
puts "ΥǤ, ϿƤκɸԤޤ."

s = "ü [degree]"
input_str = input_str+"&map_info\n"+val_make( "lon_min", s )

s = "ü [degree]"
input_str = input_str+val_make( "lat_min", s )

s = "ηٴֳ [degree]"
input_str = input_str+val_make( "dlon", s )

s = "ΰٴֳ [degree]"
input_str = input_str+val_make( "dlat", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 5 (&map_info) μϽλޤ."

####### Section 6 #########
puts "Section 6 : &val_cont ."
puts "ΥǤ, ɤ߹ѿԤޤ."
puts ", ɤ߹ '1', ɤ߹ޤʤ '0' "
puts "ꤷƲ. ˤ, ctl ե뤫, log.solver 򻲾ȤƲ."

s = "ǽ˵Ͽ 2d ǡѿ [char : ex. '1100101']"
input_str = input_str+"&val_cont\n"+val_make( "d2valc", s )

s = "ǽ˵Ͽ 3d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "d3valc", s )

s = "˵Ͽ 2d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "ad2valc", s )

s = "˵Ͽ 3d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "ad3valc", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 6 (&val_cont) μϽλޤ."


####### Section 7 #########
puts "Section 7 : &val_cont ."
puts "ΥǤ, ץѿꤷޤ."

s = " x ʻֹ [integer, 2 array]"
input_str = input_str+"&option\n"+val_make( "nnx", s )

s = " y ʻֹ [integer, 2 array]"
input_str = input_str+val_make( "nny", s )

s = " z ʻֹ [integer, 2 array]"
input_str = input_str+val_make( "nnz", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 7 (&option) μϽλޤ."

####### Section 8 #########
puts "Section 8 : &factor ."
puts "ΥǤ, ѿΥեꤷޤ."

s = " shade ѿΥե [real]"
input_str = input_str+"&factor\n"+val_make( "sfact", s )

s = " contour ѿΥե [real]"
input_str = input_str+val_make( "contour", s )

s = " ٥ȥ x ʬѿΥե [real]"
input_str = input_str+val_make( "vxfact", s )+"/\n"

s = " ٥ȥ y ʬѿΥե [real]"
input_str = input_str+val_make( "vyfact", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 8 (&factor) μϽλޤ."
puts "ʾ, namelist ꤬λޤ."
puts "ʤꤷͤϰʲΤȤǤ."
puts "#######################################"
puts input_str
puts "#######################################"
puts "ʾǤ褱, ե¸ޤ. [y/N]"
point = gets.chomp()

if point == "y"
   puts "¸ե̾ϤƲ."
   fname = gets.chomp()
   file = File.open(fname,'w')
   file.puts( input_str )
   file.close
   puts "ե #{fname} ¸ޤ."
else
   puts "˴ޤ. ꤷʤʤ, ⤦٥ץȤ¹ԤƲ."
   return 0
end

==> libdclaf90-0.60.tar.gz: libdclaf90-0.60/manual/dcl_nml_make.rb <==
#########################################
# ܥץȤ dcl-f90 ץ   #
# ¹Ԥ뤿 namelist ÷  #
# 륹ץȤǤ.               #
# , GTK Ѥƥե  #
# ǤФȻפޤ.                   #
# 2010/11/27 ҵ                   #
#########################################
$KCODE = "euc-jp"

def val_make(vname,input_name)
# vname = ѿ̾, input_name = Ϥѿơܸġ
puts "#{input_name} ϤƲ. [#{vname}]"
val = gets()
str = "#{vname} = #{val}"
puts str
return str
end

def val_make_opt(vname,input_name,opt)
# val_make Υǥեͤ˷ޤäƤ
# ξǤ, ǥեͤϤʤФʤʤ(ײ)
# vname = ѿ̾, input_name = Ϥѿơܸġ
puts "#{input_name} ϤƲ. [#{vname}]"
puts "ǥեͤ [#{vname} = #{opt}] Ǥ."
val = gets()
str = "#{vname} = #{val}"
puts str
return str
end


mae = <<"EOF"
ˤ.
줫 DCL-f90 ¹Ԥ뤿 namelist ե
ԤåץȤưޤ.
ʤ, ʲμƲ.
ޤ, ȯʳˤ뤿, 顼ʤɤϰڹԤäƤʤΤ,
жʻȤϤʤǤ.
ȤǤʤ顼򾷤.

ʤǤʤ, "yes", ưʤʤ "no" ϤƲ.
EOF

puts mae

str1 = gets()

if str1=="no\n"
   puts 'ޤۤ.'
   return 0
end

puts str1

####### Section 1 #########
puts "Section 1 : &input ."
puts "ΥǤ, ׻ΰʻʤɤνפԤޤ."

s = "γʻ"
input_str = "&input\n"+val_make( "nx", s )

s = "γʻ"
input_str = input_str+val_make( "ny", s )

s = "ľγʻ"
input_str = input_str+val_make( "nz", s )

s = "üκɸ"
input_str = input_str+val_make_opt( "xmin", s, 0.0 )

s = "üκɸ"
input_str = input_str+val_make_opt( "ymin", s, 0.0 )

s = "ľβüκɸ"
input_str = input_str+val_make( "zmin", s )

s = "γʻҴֳ [m]"
input_str = input_str+val_make( "dx", s )

s = "γʻҴֳ [m]"
input_str = input_str+val_make( "dy", s )

s = "ľγʻҴֳ [m]"
input_str = input_str+val_make( "dz", s )
# , ȥåץˤбƤޤ.

s = "ɤ߹ե"
input_str = input_str+val_make( "fnumber", s )

s = "ɤ߹եλֳִ֡Ϣֳִ֡ [integer]"
input_str = input_str+val_make( "dt", s )

s = "ɤ߹ geography եκ쥳ֹ"
input_str = input_str+val_make( "grd_rec", s )

s = "ɤʬ"
input_str = input_str+val_make( "shade_num", s )

s = "顼ɤκ"
input_str = input_str+val_make( "cmin", s )

s = "顼ɤκ"
input_str = input_str+val_make( "cmax", s )

s = "κ"
input_str = input_str+val_make( "contmin", s )

s = "κ"
input_str = input_str+val_make( "contmax", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 1 (&input) μϽλޤ."

####### Section 2 #########
puts "Section 2 : &filename ."
puts "ΥǤ, ɤ߹եΥإåɤ߹ߤ򳫻ϤեԤޤ."

s = "ɤ߹եΥإå [char]"
str1 =<<"EOE" 
[] : ΥץǤ, ɤ߹եֳ֤Ϣ֤ȤʤäƤ뤳ȤꤷƤޤ.
ä, ϤإåȤ, Ϣ֤οľޤǤؤޤΤ,
Ϥʸ, Ϣ֤ľޤǤΥե̾Ȥʤޤ.
ʤ, ʲμ, [char] ɽΤѿˤĤƤ, ϻ˥󥰥륯ơǰϤǲ.
EOE
puts str1
input_str = input_str+"&filename\n"+val_make( "hname", s )

s = "ɤ߹եΥեå (ĥҤޤϢֹľ) [char]"
input_str = input_str+val_make( "footname", s )

s = "ɤ߹եϢ֤κǤͤ"
input_str = input_str+val_make( "ininame", s )

s = "geography ե̾ [char]"
input_str = input_str+val_make( "grdname", s )

s = "դΥȥ̾ [char]"
str1 =<<"EOE" 
[] : Ǥ륿ȥ̾ DCL ΰʸ¤˰¸ޤ. ʤ, ȥθźǻ֤ͤˤʤäƤΤ, θꤷƤ.
EOE
puts str1
input_str = input_str+val_make( "title_name", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 2 (&filename) μϽλޤ."

####### Section 3 #########
puts "Section 3 : &file_form ."
puts "ΥǤ, DCL ΥդɽͤΥեޥåԤޤ."

s = "ɽͤΥեޥå [(f?.?), char]"
input_str = input_str+"&file_form\n"+val_make( "form_typec", s )

s = "顼СɽͤΥեޥå [(f?.?), char]"
input_str = input_str+val_make( "form_types", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 3 (&file_form) μϽλޤ."

####### Section 4 #########
puts "Section 4 : &dcl_dump ."
puts "ΥǤ, DCL Υ֤˴ؤԤޤ."

s = "դե¸뤫ɤ [.false., .true.]"
str1 =<<"EOD"
[] : ʲꤹ IWS ͤ 2 ξ϶Ū¸ޤ.
EOD
puts str1
input_str = input_str+"&dcl_dump\n"+val_make( "ldump", s )

s = "Return 򲡤Ʋڡ뤫ɤ [.false., .true.]"
input_str = input_str+val_make( "lwait", s )

s = "Return 򲡤ƥդν֤Ĥɤ [.false., .true.]"
input_str = input_str+val_make( "lwait1", s )

s = "DCL νֹ [integer]"
input_str = input_str+val_make( "IWS", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 4 (&dcl_dump) μϽλޤ."

####### Section 5 #########
puts "Section 5 : &map_info ."
puts "ΥǤ, ϿƤκɸԤޤ."

s = "ü [degree]"
input_str = input_str+"&map_info\n"+val_make( "lon_min", s )

s = "ü [degree]"
input_str = input_str+val_make( "lat_min", s )

s = "ηٴֳ [degree]"
input_str = input_str+val_make( "dlon", s )

s = "ΰٴֳ [degree]"
input_str = input_str+val_make( "dlat", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 5 (&map_info) μϽλޤ."

####### Section 6 #########
puts "Section 6 : &val_cont ."
puts "ΥǤ, ɤ߹ѿԤޤ."
puts ", ɤ߹ '1', ɤ߹ޤʤ '0' "
puts "ꤷƲ. ˤ, ctl ե뤫, log.solver 򻲾ȤƲ."

s = "ǽ˵Ͽ 2d ǡѿ [char : ex. '1100101']"
input_str = input_str+"&val_cont\n"+val_make( "d2valc", s )

s = "ǽ˵Ͽ 3d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "d3valc", s )

s = "˵Ͽ 2d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "ad2valc", s )

s = "˵Ͽ 3d ǡѿ [char : ex. '1100101']"
input_str = input_str+val_make( "ad3valc", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 6 (&val_cont) μϽλޤ."


####### Section 7 #########
puts "Section 7 : &val_cont ."
puts "ΥǤ, ץѿꤷޤ."

s = " x ʻֹ [integer, 2 array]"
input_str = input_str+"&option\n"+val_make( "nnx", s )

s = " y ʻֹ [integer, 2 array]"
input_str = input_str+val_make( "nny", s )

s = " z ʻֹ [integer, 2 array]"
input_str = input_str+val_make( "nnz", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 7 (&option) μϽλޤ."

####### Section 8 #########
puts "Section 8 : &factor ."
puts "ΥǤ, ѿΥեꤷޤ."

s = " shade ѿΥե [real]"
input_str = input_str+"&factor\n"+val_make( "sfact", s )

s = " contour ѿΥե [real]"
input_str = input_str+val_make( "contour", s )

s = " ٥ȥ x ʬѿΥե [real]"
input_str = input_str+val_make( "vxfact", s )+"/\n"

s = " ٥ȥ y ʬѿΥե [real]"
input_str = input_str+val_make( "vyfact", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 8 (&factor) μϽλޤ."

####### Section 9 #########
puts "Section 9 : &cress ."
puts "ΥǤ, ľȥå򤷤ޤ."
puts ", CReSS  namelist եƱͤꤷƲ."

s = " sthopt ȥå󥰤μ [int]"
input_str = input_str+"&cress\n"+val_make( "sthopt", s )

s = " dzmin ǲؤγʻҴֳ [real]"
input_str = input_str+val_make( "dzmin", s )

s = " layer1 ȥå󥰳Ϲ [real]"
input_str = input_str+val_make( "layer1", s )+"/\n"

s = " layer2 ȥå󥰽λ [real]"
input_str = input_str+val_make( "layer2", s )+"/\n"
input_str = input_str+"\n"


puts "ʾ, Section 9 (&cress) μϽλޤ."
puts "ʾ, namelist ꤬λޤ."
puts "ʤꤷͤϰʲΤȤǤ."
puts "#######################################"
puts input_str
puts "#######################################"
puts "ʾǤ褱, ե¸ޤ. [y/N]"
point = gets.chomp()

if point == "y"
   puts "¸ե̾ϤƲ."
   fname = gets.chomp()
   file = File.open(fname,'w')
   file.puts( input_str )
   file.close
   puts "ե #{fname} ¸ޤ."
else
   puts "˴ޤ. ꤷʤʤ, ⤦٥ץȤ¹ԤƲ."
   return 0
end
